| sr-package | R Documentation |
Finds causal connections in precision data, finds lags and embeddings in time series, guides training of neural networks and other smooth models, evaluates their performance, gives a mathematically grounded answer to the over-training problem. Smooth regression is based on the Gamma test, which measures smoothness in a multivariate relationship. Causal relations are smooth, noise is not. 'sr' includes the Gamma test and search techniques that use it. References: Evans & Jones (2002) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1098/rspa.2002.1010")}, AJ Jones (2004) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1007/s10287-003-0006-1")}.
Maintainer: Wayne Haythorn support@smoothregression.com
Authors:
Antonia Jones (Principal creator of the Gamma test)
Other contributors:
Sam Kemp (Wrote the original code for the Gamma test in R) [contributor]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.